@@ -3,13 +3,17 @@
 #' 
 #' @param x numeric. The distance to be converted.
 #' @param from,to character. Units to convert from and to. Can be "km" (kilometers), 
-#' "nm" (nautical miles), or "mi" (statute miles).
+#'   "nm" (nautical miles), or "mi" (statute miles), or any partial match 
+#'   thereof (case sensitive).
 #' 
 #' @author Eric Archer \email{eric.archer@@noaa.gov}
 #' 
 #' @export
 #' 
-convert.distance <- function(x, from = "nm", to = "km") {
+convert.distance <- function(x, from = c("nm", "km", "mi"), to = c("km", "nm", "mi")) {
+  from <- match.arg(from)
+  to <- match.arg(to)
+  
   x <- switch(from,
     km = x,
     nm = x * 1.852,
